@@ -138,11 +138,11 @@ def full_line_model(channel, wdm, bits_x=None, bits_y=None, points_x=None, point
     e_signal_x_prop = get_energy(signal_x, dt * np_signal)
     e_signal_y_prop = get_energy(signal_y, dt * np_signal)
 
-    print("Signal energy before propagation (x / y):", e_signal_x, e_signal_y)
-    print("Signal energy after propagation (x / y):", e_signal_x_prop, e_signal_y_prop)
-    print("Signal energy difference (x / y):",
-          np.absolute(e_signal_x - e_signal_x_prop),
-          np.absolute(e_signal_y - e_signal_y_prop))
+    # print("Signal energy before propagation (x / y):", e_signal_x, e_signal_y)
+    # print("Signal energy after propagation (x / y):", e_signal_x_prop, e_signal_y_prop)
+    # print("Signal energy difference (x / y):",
+    #       np.absolute(e_signal_x - e_signal_x_prop),
+    #       np.absolute(e_signal_y - e_signal_y_prop))
 
     samples_x, samples_y = receiver(signal_x, signal_y, ft_filter_values, wdm['downsampling_rate'])
     samples_x, samples_y = dispersion_compensation_manakov(channel, samples_x, samples_y, dt * wdm['downsampling_rate'])
@@ -167,7 +167,7 @@ def full_line_model(channel, wdm, bits_x=None, bits_y=None, points_x=None, point
     ber_y = get_ber_by_points(points_orig_y * scale_constellation, points_y_found, mod_type)
 
     # print("BER (x / y):", BER_est(wdm['m_order'], points_x_shifted, points_orig_x), BER_est(wdm['m_order'], points_y_shifted, points_orig_y))
-    print("BER (x / y):", ber_x, ber_y)
+    # print("BER (x / y):", ber_x, ber_y)
 
     result = {
         'points_x': points_x,
